==> haskell-attoparsec-iso8601-1.0.0.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-eLsKJPPzeLHFgNC0Hosru
key: attoparsec-iso8601-1.0.0.0-eLsKJPPzeLHFgNC0Hosru
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec.Time.Internal Data.Attoparsec.Time
abi: b9a81b55bfc69b5ebe93a38f915d1386
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-iso8601-1.0.0.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-eLsKJPPzeLHFgNC0Hosru
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-4Cy3sWiD35aDIhceTob3aO
key: attoparsec-iso8601-1.0.0.0-4Cy3sWiD35aDIhceTob3aO
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec.Time.Internal Data.Attoparsec.Time
abi: ffde9a6dbfd589ea7e31918ae82afda8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-iso8601-1.0.0.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-4Cy3sWiD35aDIhceTob3aO
depends:
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
